==> haskell-pandoc-crossref-0.2.5.0-36-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.5.0
id: pandoc-crossref-0.2.5.0-1HgscqTZD2153Os2ScM0ob
key: pandoc-crossref-0.2.5.0-1HgscqTZD2153Os2ScM0ob
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: fc5aed7a76766b17bdb9fd7c8b5fa218
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.5.0-1HgscqTZD2153Os2ScM0ob
depends:
    base-4.9.0.0 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-9rU3hJ3Wexf6m7EcZLYdbr
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-1.19.2.1-I7Hny55Vn8D3ZeiIZ9wJD1
    pandoc-types-1.17.0.5-11Nd20rWWmXXKwn0ardsS
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    utility-ht-0.0.13-6LFtwAy4r2q397pbhjrZza
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-crossref-0.2.5.0-42-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.5.0
id: pandoc-crossref-0.2.5.0-9DRLgdoZoSXJf9u2NrX2IY
key: pandoc-crossref-0.2.5.0-9DRLgdoZoSXJf9u2NrX2IY
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 9e912a068a817c9c25a52a3929ea8dfa
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.5.0
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.5.0-9DRLgdoZoSXJf9u2NrX2IY
depends:
    base-4.9.0.0 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-9rU3hJ3Wexf6m7EcZLYdbr
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pandoc-1.19.2.1-E7vqJ2dxBCQ3Mzhp2w71i4
    pandoc-types-1.17.0.5-EUUdZhfkCxT86pl6CKpjbW
    roman-numerals-0.5.1.5-CRymvVwv5tbH73xozocxyM
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    utility-ht-0.0.13-6LFtwAy4r2q397pbhjrZza
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
